@@ -25,7 +25,7 @@ if __name__ == '__main__':
     print()
     print('       ---------------------------')
     print('       - Python YI MicroPython   -')
-    print('       -      version 1.0.2      -')
+    print('       -      version 1.0.5      -')
     print('       -     by YI               -')
     print('       ---------------------------')
     print()
@@ -35,7 +35,7 @@ if __name__ == '__main__':
     except ImportError:
         pass
     WebREPL.start(password=webrepl_pass())
-    from emp_ide import *'''
+    import ide'''
 
 
 def reboot():
@@ -85,9 +85,6 @@ def set_boot_mode():
 def set_web_repl():
     pw = input(rainbow('请输入新的WebREPL密码：', color='blue'))
     config_path()
-    if not 'webrepl.pass' in os.listdir('config'):
-        with open('config/webrepl.pass', 'w') as c:
-            c.write(pw)
-    print(rainbow('已重新设置WebREPL密码', color='green'))
-
-    reboot()
+    with open('config/webrepl.pass', 'w') as c:
+        c.write(pw)
+    print(rainbow('已重新设置WebREPL密码，重启之后可用！！！', color='green'))
